# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class AccessibleTextType(metaclass=UnoConstMeta, type_name="com.sun.star.accessibility.AccessibleTextType", name_space="com.sun.star.accessibility"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.accessibility.AccessibleTextType``"""
        pass

    class AccessibleTextTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.accessibility.AccessibleTextType", name_space="com.sun.star.accessibility"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.accessibility.AccessibleTextType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.accessibility import AccessibleTextType as AccessibleTextType
    else:
        # keep document generators happy
        from ...lo.accessibility.accessible_text_type import AccessibleTextType as AccessibleTextType

    class AccessibleTextTypeEnum(IntEnum):
        """
        Enum of Const Class AccessibleTextType

        Collection of types of text portions.
        
        This collection describes the types of text portions that can be accessed with the help of the methods of the XAccessibleText interface.
        
        **since**
        
            OOo 1.1.2
        """
        CHARACTER = AccessibleTextType.CHARACTER
        """
        Single character.
        
        Indicates that single (multibyte) characters are used.
        """
        WORD = AccessibleTextType.WORD
        """
        Single word.
        
        Indicates that single words are used. The definition of what a word is, is implementation and language/locale dependent. While in English a word is ended by a space or a special character like a comma or a period, this is not necessarily true in other languages.
        """
        SENTENCE = AccessibleTextType.SENTENCE
        """
        Single sentence.
        
        Indicates that single sentences are used. The definition of what a sentence is, is implementation and language/locale dependent. While in English a sentence is ended by a period, this is not necessarily true in other languages.
        """
        PARAGRAPH = AccessibleTextType.PARAGRAPH
        """
        Single paragraph.
        
        Indicates that single paragraphs are used. The definition of what a paragraph is, is implementation and language/locale dependent.
        """
        LINE = AccessibleTextType.LINE
        """
        Single line.
        
        Indicates that single lines, as displayed on the screen, are used. In contrast to the constants CHARACTER, WORD, SENTENCE, and PARAGRAPH which are content oriented this constant is view oriented. It can be used to retrieve hyphenation information.
        """
        GLYPH = AccessibleTextType.GLYPH
        """
        Single glyph.
        
        Glyphs are runs of one or more (multibyte) characters which are displayed as one symbol.
        """
        ATTRIBUTE_RUN = AccessibleTextType.ATTRIBUTE_RUN
        """
        Attribute run.
        
        Each attribute run is a character run of maximal length where all characters have the same attributes set.
        """

__all__ = ['AccessibleTextType', 'AccessibleTextTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ConversionPropertyType(metaclass=UnoConstMeta, type_name="com.sun.star.linguistic2.ConversionPropertyType", name_space="com.sun.star.linguistic2"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.linguistic2.ConversionPropertyType``"""
        pass

    class ConversionPropertyTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.linguistic2.ConversionPropertyType", name_space="com.sun.star.linguistic2"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.linguistic2.ConversionPropertyType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.linguistic2 import ConversionPropertyType as ConversionPropertyType
    else:
        # keep document generators happy
        from ...lo.linguistic2.conversion_property_type import ConversionPropertyType as ConversionPropertyType

    class ConversionPropertyTypeEnum(IntEnum):
        """
        Enum of Const Class ConversionPropertyType

        specifies the property type of an entry in a conversion dictionary.
        
        **since**
        
            OOo 2.0
        """
        NOT_DEFINED = ConversionPropertyType.NOT_DEFINED
        """
        There is no property type defined or available.
        """
        OTHER = ConversionPropertyType.OTHER
        """
        Any word that does not fit into any of the other properties.
        """
        FOREIGN = ConversionPropertyType.FOREIGN
        """
        A word or term that is transliterated or used from a non-Chinese language.
        """
        FIRST_NAME = ConversionPropertyType.FIRST_NAME
        """
        The first name (given name) of a person.
        """
        LAST_NAME = ConversionPropertyType.LAST_NAME
        """
        The last name (family name) of a person.
        """
        TITLE = ConversionPropertyType.TITLE
        """
        The academic or social title of a person.
        """
        STATUS = ConversionPropertyType.STATUS
        """
        The status of a situation.
        """
        PLACE_NAME = ConversionPropertyType.PLACE_NAME
        """
        The name of a location or place.
        """
        BUSINESS = ConversionPropertyType.BUSINESS
        """
        The description of a business.
        """
        ADJECTIVE = ConversionPropertyType.ADJECTIVE
        """
        An adjective.
        """
        IDIOM = ConversionPropertyType.IDIOM
        """
        A term that is used to literally describe a circumstance.
        """
        ABBREVIATION = ConversionPropertyType.ABBREVIATION
        """
        An abbreviation.
        """
        NUMERICAL = ConversionPropertyType.NUMERICAL
        """
        A numeric word.
        """
        NOUN = ConversionPropertyType.NOUN
        """
        A noun.
        """
        VERB = ConversionPropertyType.VERB
        """
        A verb.
        """
        BRAND_NAME = ConversionPropertyType.BRAND_NAME
        """
        The name of a product or a company.
        """

__all__ = ['ConversionPropertyType', 'ConversionPropertyTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .url_record import UrlRecord as UrlRecord_8f510a4d
    from .x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XPasswordContainer(XInterface_8f010a43):
    """
    Allows to save passwords with URL-pattern, to use them later.

    See Also:
        `API XPasswordContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XPasswordContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.XPasswordContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.task.XPasswordContainer'

    @abstractmethod
    def add(self, Url: str, UserName: str, Passwords: typing.Tuple[str, ...], Handler: XInteractionHandler_bf80e51) -> None:
        """
        Save passwords into the container.
        """
        ...
    @abstractmethod
    def addPersistent(self, Url: str, UserName: str, Passwords: typing.Tuple[str, ...], Handler: XInteractionHandler_bf80e51) -> None:
        """
        Save passwords into the container, and store them in the file.
        """
        ...
    @abstractmethod
    def find(self, Url: str, Handler: XInteractionHandler_bf80e51) -> UrlRecord_8f510a4d:
        """
        Find users with passwords for the url pattern.
        """
        ...
    @abstractmethod
    def findForName(self, Url: str, UserName: str, Handler: XInteractionHandler_bf80e51) -> UrlRecord_8f510a4d:
        """
        Find passwords for the url pattern and username.
        """
        ...
    @abstractmethod
    def getAllPersistent(self, Handler: XInteractionHandler_bf80e51) -> typing.Tuple[UrlRecord_8f510a4d, ...]:
        """
        Get all records from the file.
        """
        ...
    @abstractmethod
    def remove(self, Url: str, UserName: str) -> None:
        """
        Remove passwords for the url pattern and username.
        """
        ...
    @abstractmethod
    def removeAllPersistent(self) -> None:
        """
        Clean the file.
        """
        ...
    @abstractmethod
    def removePersistent(self, Url: str, UserName: str) -> None:
        """
        Remove passwords for the url pattern and username from the file.
        """
        ...

__all__ = ['XPasswordContainer']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6

class HierarchyDataSource(XComponent_98dc0ab5, XMultiServiceFactory_191e0eb6):
    """
    Service Class

    manages one or more complete sets of hierarchy data and serves as a factory for objects that provide access to a subset of the data.
    
    Note: This is an abstract service. This means, that there should never be implementations that can be instantiated using the service name com.sun.star.ucb.HierarchyDataSource. Each implementation must provide its own service name that can be used to create instances of that service implementation. Important for those service specifications is also to specify which of the optional parts are supported by the implementation.

    See Also:
        `API HierarchyDataSource <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1HierarchyDataSource.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.HierarchyDataSource'
    __ooo_type_name__: str = 'service'


__all__ = ['HierarchyDataSource']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XModuleManager(XInterface_8f010a43):
    """
    can be used to identify office modules.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XModuleManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XModuleManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XModuleManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XModuleManager'

    @abstractmethod
    def identify(self, Module: XInterface_8f010a43) -> str:
        """
        identifies the given module.
        
        This identifier can then be used at the service ModuleManager to get more information about this module.
        
        For identification the interface com.sun.star.lang.XServiceInfo is requested on the given module. Because all module service registrations must be unique this value can be queried and checked against the configuration.
        
        Since OOo 2.3.0 also the optional interface XModule will be used. If its exists it will be preferred.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            UnknownModuleException: ``UnknownModuleException``
        """
        ...

__all__ = ['XModuleManager']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.sdb.tools.composition_type import CompositionType as CompositionType
with suppress(ImportError):
    from ....dyn.sdb.tools.composition_type import CompositionTypeEnum as CompositionTypeEnum
with suppress(ImportError):
    from ....dyn.sdb.tools.connection_tools import ConnectionTools as ConnectionTools
with suppress(ImportError):
    from ....dyn.sdb.tools.x_connection_supplier import XConnectionSupplier as XConnectionSupplier
with suppress(ImportError):
    from ....dyn.sdb.tools.x_connection_tools import XConnectionTools as XConnectionTools
with suppress(ImportError):
    from ....dyn.sdb.tools.x_data_source_meta_data import XDataSourceMetaData as XDataSourceMetaData
with suppress(ImportError):
    from ....dyn.sdb.tools.x_index_alteration import XIndexAlteration as XIndexAlteration
with suppress(ImportError):
    from ....dyn.sdb.tools.x_key_alteration import XKeyAlteration as XKeyAlteration
with suppress(ImportError):
    from ....dyn.sdb.tools.x_object_names import XObjectNames as XObjectNames
with suppress(ImportError):
    from ....dyn.sdb.tools.x_table_alteration import XTableAlteration as XTableAlteration
with suppress(ImportError):
    from ....dyn.sdb.tools.x_table_name import XTableName as XTableName
with suppress(ImportError):
    from ....dyn.sdb.tools.x_table_rename import XTableRename as XTableRename
with suppress(ImportError):
    from ....dyn.sdb.tools.x_view_access import XViewAccess as XViewAccess



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.browse
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XBrowseNode(XInterface_8f010a43):
    """
    This interface represents a node in the hierarchy used to browse available scripts.
    
    Objects implementing this interface are expected to also implement com.sun.star.beans.XPropertySet and, optionally, com.sun.star.script.XInvocation (see the Developer's Guide for more details).

    See Also:
        `API XBrowseNode <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1browse_1_1XBrowseNode.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script.browse'
    __ooo_full_ns__: str = 'com.sun.star.script.browse.XBrowseNode'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.browse.XBrowseNode'

    @abstractmethod
    def getChildNodes(self) -> typing.Tuple[XBrowseNode, ...]:
        """
        Get the children of this node.
        """
        ...
    @abstractmethod
    def getName(self) -> str:
        """
        Get the name of the node.
        """
        ...
    @abstractmethod
    def getType(self) -> int:
        """
        the type of the node.
        """
        ...
    @abstractmethod
    def hasChildNodes(self) -> bool:
        """
        Indicates if this node contains any children.
        """
        ...

__all__ = ['XBrowseNode']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
from .conversion_dictionary import ConversionDictionary as ConversionDictionary_8fa111b1

class HangulHanjaConversionDictionary(ConversionDictionary_8fa111b1):
    """
    Service Class

    represents a dictionary for Hangul/Hanja text conversion.
    
    A dictionary implementing this service will be used for Hangul/Hanja conversion. Therefore the locale of the dictionary has to be Korean, and the conversion type com.sun.star.linguistic2.ConversionDictionaryType.HANGUL_HANJA.
    
    Also for a pair (entry) to be added the left part has to be in Hangul and the right in Hanja, and the number of characters for the left part has to be the same as for the right part.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API HangulHanjaConversionDictionary <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1linguistic2_1_1HangulHanjaConversionDictionary.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.HangulHanjaConversionDictionary'
    __ooo_type_name__: str = 'service'


__all__ = ['HangulHanjaConversionDictionary']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class EnhancedCustomShapeSegmentCommand(metaclass=UnoConstMeta, type_name="com.sun.star.drawing.EnhancedCustomShapeSegmentCommand", name_space="com.sun.star.drawing"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.drawing.EnhancedCustomShapeSegmentCommand``"""
        pass

    class EnhancedCustomShapeSegmentCommandEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.drawing.EnhancedCustomShapeSegmentCommand", name_space="com.sun.star.drawing"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.drawing.EnhancedCustomShapeSegmentCommand`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.drawing import EnhancedCustomShapeSegmentCommand as EnhancedCustomShapeSegmentCommand
    else:
        # keep document generators happy
        from ...lo.drawing.enhanced_custom_shape_segment_command import EnhancedCustomShapeSegmentCommand as EnhancedCustomShapeSegmentCommand

    class EnhancedCustomShapeSegmentCommandEnum(IntEnum):
        """
        Enum of Const Class EnhancedCustomShapeSegmentCommand

        """
        UNKNOWN = EnhancedCustomShapeSegmentCommand.UNKNOWN
        MOVETO = EnhancedCustomShapeSegmentCommand.MOVETO
        LINETO = EnhancedCustomShapeSegmentCommand.LINETO
        CURVETO = EnhancedCustomShapeSegmentCommand.CURVETO
        CLOSESUBPATH = EnhancedCustomShapeSegmentCommand.CLOSESUBPATH
        ENDSUBPATH = EnhancedCustomShapeSegmentCommand.ENDSUBPATH
        NOFILL = EnhancedCustomShapeSegmentCommand.NOFILL
        NOSTROKE = EnhancedCustomShapeSegmentCommand.NOSTROKE
        ANGLEELLIPSETO = EnhancedCustomShapeSegmentCommand.ANGLEELLIPSETO
        ANGLEELLIPSE = EnhancedCustomShapeSegmentCommand.ANGLEELLIPSE
        ARCTO = EnhancedCustomShapeSegmentCommand.ARCTO
        ARC = EnhancedCustomShapeSegmentCommand.ARC
        CLOCKWISEARCTO = EnhancedCustomShapeSegmentCommand.CLOCKWISEARCTO
        CLOCKWISEARC = EnhancedCustomShapeSegmentCommand.CLOCKWISEARC
        ELLIPTICALQUADRANTX = EnhancedCustomShapeSegmentCommand.ELLIPTICALQUADRANTX
        ELLIPTICALQUADRANTY = EnhancedCustomShapeSegmentCommand.ELLIPTICALQUADRANTY
        QUADRATICCURVETO = EnhancedCustomShapeSegmentCommand.QUADRATICCURVETO
        ARCANGLETO = EnhancedCustomShapeSegmentCommand.ARCANGLETO
        DARKEN = EnhancedCustomShapeSegmentCommand.DARKEN
        """
        darken fill color
        """
        DARKENLESS = EnhancedCustomShapeSegmentCommand.DARKENLESS
        """
        darken fill color less
        """
        LIGHTEN = EnhancedCustomShapeSegmentCommand.LIGHTEN
        """
        lighten fill color
        """
        LIGHTENLESS = EnhancedCustomShapeSegmentCommand.LIGHTENLESS
        """
        lighten fill color less
        """

__all__ = ['EnhancedCustomShapeSegmentCommand', 'EnhancedCustomShapeSegmentCommandEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class KeyStroke(object):
    """
    Struct Class

    Describes a key stroke for hotkeys etc.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API KeyStroke <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1KeyStroke.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.KeyStroke'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.KeyStroke'
    """Literal Constant ``com.sun.star.awt.KeyStroke``"""

    def __init__(self, Modifiers: typing.Optional[int] = 0, KeyCode: typing.Optional[int] = 0, KeyChar: typing.Optional[str] = '\u0000', KeyFunc: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Modifiers (int, optional): Modifiers value.
            KeyCode (int, optional): KeyCode value.
            KeyChar (str, optional): KeyChar value.
            KeyFunc (int, optional): KeyFunc value.
        """
        super().__init__()

        if isinstance(Modifiers, KeyStroke):
            oth: KeyStroke = Modifiers
            self.Modifiers = oth.Modifiers
            self.KeyCode = oth.KeyCode
            self.KeyChar = oth.KeyChar
            self.KeyFunc = oth.KeyFunc
            return

        kargs = {
            "Modifiers": Modifiers,
            "KeyCode": KeyCode,
            "KeyChar": KeyChar,
            "KeyFunc": KeyFunc,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._modifiers = kwargs["Modifiers"]
        self._key_code = kwargs["KeyCode"]
        self._key_char = kwargs["KeyChar"]
        self._key_func = kwargs["KeyFunc"]


    @property
    def Modifiers(self) -> int:
        """
        contains the modifier keys which were pressed while the event occurred.
        
        Zero or more constants from the group com.sun.star.awt.KeyModifier.
        """
        return self._modifiers

    @Modifiers.setter
    def Modifiers(self, value: int) -> None:
        self._modifiers = value

    @property
    def KeyCode(self) -> int:
        """
        contains the integer code representing the key of the event.
        
        This is a constant from the constant group com.sun.star.awt.Key.
        """
        return self._key_code

    @KeyCode.setter
    def KeyCode(self, value: int) -> None:
        self._key_code = value

    @property
    def KeyChar(self) -> str:
        """
        contains the Unicode character generated by this event or 0.
        """
        return self._key_char

    @KeyChar.setter
    def KeyChar(self, value: str) -> None:
        self._key_char = value

    @property
    def KeyFunc(self) -> int:
        """
        contains the function type of the key event.
        
        This is a constant from the constant group com.sun.star.awt.KeyFunction.
        """
        return self._key_func

    @KeyFunc.setter
    def KeyFunc(self, value: int) -> None:
        self._key_func = value


__all__ = ['KeyStroke']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.drawing.EscapeDirection import EscapeDirectionProto

class EscapeDirection(Enum):
    """
    Enum Class


    See Also:
        `API EscapeDirection <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a554864869ec34ebdfb5ecde01c5c5670>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.EscapeDirection'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.drawing.EscapeDirection'

    DOWN = cast("EscapeDirectionProto", 'DOWN')
    """
    """
    HORIZONTAL = cast("EscapeDirectionProto", 'HORIZONTAL')
    """
    mirror to the horizontal axis
    """
    LEFT = cast("EscapeDirectionProto", 'LEFT')
    """
    the connection line leaves the connected object to the left,
    
    The left edge of the text is adjusted to the left edge of the shape.
    
    The text is positioned to the left.
    """
    RIGHT = cast("EscapeDirectionProto", 'RIGHT')
    """
    the connection line leaves the connected object to the right,
    
    The right edge of the text is adjusted to the right edge of the shape.
    
    The text is positioned to the right.
    """
    SMART = cast("EscapeDirectionProto", 'SMART')
    """
    """
    UP = cast("EscapeDirectionProto", 'UP')
    """
    """
    VERTICAL = cast("EscapeDirectionProto", 'VERTICAL')
    """
    mirror to the vertical axis
    """

__all__ = ['EscapeDirection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.form.ListSourceType import ListSourceTypeProto

class ListSourceType(Enum):
    """
    Enum Class


    See Also:
        `API ListSourceType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form.html#a52e06ed91fb133bc98c089a401a724fb>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.ListSourceType'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.form.ListSourceType'

    QUERY = cast("ListSourceTypeProto", 'QUERY')
    """
    The control should be filled with the results of a database query.
    """
    SQL = cast("ListSourceTypeProto", 'SQL')
    """
    The control should be filled with the results of a database statement.
    """
    SQLPASSTHROUGH = cast("ListSourceTypeProto", 'SQLPASSTHROUGH')
    """
    The control should be filled with the results of a database statement, which is not evaluated by the database engine.
    """
    TABLE = cast("ListSourceTypeProto", 'TABLE')
    """
    The control should be filled with the data of a table.
    """
    TABLEFIELDS = cast("ListSourceTypeProto", 'TABLEFIELDS')
    """
    The control should be filled with the field names of a database table.
    """
    VALUELIST = cast("ListSourceTypeProto", 'VALUELIST')
    """
    The control should be filled with a list of string values.
    """

__all__ = ['ListSourceType']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xforms
from __future__ import annotations
import typing
from abc import abstractproperty
from ..form.binding.list_entry_source import ListEntrySource as ListEntrySource_48260fe4
from ..form.binding.value_binding import ValueBinding as ValueBinding_18de0e7d
from ..form.validation.x_validator import XValidator as XValidator_2a5c0f13
if typing.TYPE_CHECKING:
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class Binding(ListEntrySource_48260fe4, ValueBinding_18de0e7d, XValidator_2a5c0f13):
    """
    Service Class

    represent a binding to one or more nodes in the DOM tree of an XModel.

    See Also:
        `API Binding <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1xforms_1_1Binding.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xforms'
    __ooo_full_ns__: str = 'com.sun.star.xforms.Binding'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BindingNamespaces(self) -> XNameContainer_cb90e47:
        """
        among other properties, there is this one
        
        It is unclear to me whether this is an implementation detail or a supported interface.
        
        The value supports the service com.sun.star.xml.NamespaceContainer
        """
        ...


__all__ = ['Binding']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_child import XChild as XChild_a6390b07
from ..drawing.x_shape import XShape as XShape_8fd00a3d
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..util.x_cloneable import XCloneable as XCloneable_99d00aa3
if typing.TYPE_CHECKING:
    from .x_section import XSection as XSection_9b630ad1

class XReportComponent(XPropertySet_bc180bfa, XChild_a6390b07, XShape_8fd00a3d, XComponent_98dc0ab5, XCloneable_99d00aa3):
    """
    describes a component which may be part of a report.

    See Also:
        `API XReportComponent <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XReportComponent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XReportComponent'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XReportComponent'

    @abstractproperty
    def DetailFields(self) -> typing.Tuple[str, ...]:
        """
        is used for subreports and contains the names of the columns of the subreport which are related to the master fields of the parent report.
        
        Entries in this sequence can either denote column names in the sub report, or parameter names.For instance, you could base the report on the SQL statement SELECT * FROM invoices WHERE cust_ref = :cid, and add cid to the DetailFields property. In this case, the parameter will be filled from the corresponding master field.Alternatively, you could simply base your report on the table invoices, and add the column name cust_ref to the DetailFields. In this case, and implicit filter clause WHERE cust_ref = :<new_param_name> will be created, and the artificial parameter will be filled from the corresponding master field.If a string in this property denotes both a column name and a parameter name, it is undefined which way it is interpreted, but implementations of the service are required to either decide for the parameter or the column, and proceed as usual.
        
        The columns specified herein typically represent a part of the primary key fields or their aliases of the detail report.
        
        If the report is no sub report (e.g. its parent is not a report itself), this property is not evaluated.
        """
        ...

    @abstractproperty
    def MasterFields(self) -> typing.Tuple[str, ...]:
        """
        is used for subreports and contains the names of columns of the parent report.
        
        These columns are typically the foreign key fields of the parent report. The values of these columns are used to identify the data for the subreport. Each time the parent report changes its current row, the subreport requeries it's data based on the values of the master fields.
        
        If the report is no sub report (e.g. its parent is not a report itself), this property is not evaluated.
        """
        ...

    @abstractproperty
    def AutoGrow(self) -> bool:
        """
        Specifies that the control containing data shall automatically grow to the optimal height to show the data without wasting space.
        """
        ...

    @abstractproperty
    def ControlBorder(self) -> int:
        """
        specifies the border style of the control.
        """
        ...

    @abstractproperty
    def ControlBorderColor(self) -> int:
        """
        specifies the color of the border, if present
        
        Not every border style (see Border) may support coloring. For instance, usually a border with 3D effect will ignore the BorderColor setting.
        """
        ...

    @abstractproperty
    def Height(self) -> int:
        """
        specifies the height of the control.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        the name of the component.
        """
        ...

    @abstractproperty
    def PositionX(self) -> int:
        """
        specifies the horizontal position of the control.
        """
        ...

    @abstractproperty
    def PositionY(self) -> int:
        """
        specifies the vertical position of the control.
        """
        ...

    @abstractproperty
    def PrintRepeatedValues(self) -> bool:
        """
        Specifies that recurring values are printed.
        
        If set to TRUE then the value will be printed every time. If set to FALSE then the value will only be printed once. The default value is TRUE.
        """
        ...

    @abstractproperty
    def Section(self) -> XSection_9b630ad1:
        """
        Specifies the section where the control belongs to.
        
        This is a shortcut to get control hierarchy up. This value is NULL when the control was not inserted in any section.
        """
        ...

    @abstractproperty
    def Width(self) -> int:
        """
        specifies the width of the control.
        """
        ...


__all__ = ['XReportComponent']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans


class MethodConcept(object):
    """
    Const Class

    These constants are used to specify concepts of the introspection which apply to methods.
    
    This list is not necessarily complete; new constants may be added.

    See Also:
        `API MethodConcept <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1beans_1_1MethodConcept.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.MethodConcept'
    __ooo_type_name__: str = 'const'

    ALL = -1
    """
    This value is used to query for all methods, see XIntrospectionAccess.getMethod() and XIntrospectionAccess.getMethods()
    """
    DANGEROUS = 1
    """
    specifies methods which can result in an unstable state (i.e.
    
    deadlock, application crash, security hole, etc.) when called directly by the user.
    """
    PROPERTY = 2
    """
    specifies methods which are used to set and get the value of properties/attributes.
    
    These methods have the signature type get...() , void set...() or boolean is...() .
    """
    LISTENER = 4
    """
    specifies methods of the listener concept.
    
    These methods have the signature add...Listener()  or remove...Listener().
    """
    ENUMERATION = 8
    """
    specifies methods of the enumeration concept.
    
    These methods have the signature create...Enumeration and return an interface that is derived from com.sun.star.container.XEnumeration. Additionally, the method com.sun.star.container.XEnumerationAccess.getElementType() belongs to this concept.
    """
    NAMECONTAINER = 16
    """
    specifies methods of the name container concept.
    
    These methods have the signature get...ByName(), set...ByName(), replace...ByName(), remove...ByName(), has...ByName(), or get...Names. In addition, the method com.sun.star.container.XEnumerationAccess.getElementType() belongs to this concept.
    """
    INDEXCONTAINER = 32
    """
    specifies methods of the index container concept.
    
    These methods have the signature get...ByIndex(), insert...ByIndex(), replace...ByIndex(), or remove...ByIndex(). The method com.sun.star.container.XIndexAccess.getCount() also belongs to this concept.
    """

__all__ = ['MethodConcept']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_hierarchical_property_set_info import XHierarchicalPropertySetInfo as XHierarchicalPropertySetInfo_ae271245

class XMultiHierarchicalPropertySet(XInterface_8f010a43):
    """
    provides access to multiple properties which form a hierarchy.

    See Also:
        `API XMultiHierarchicalPropertySet <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XMultiHierarchicalPropertySet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XMultiHierarchicalPropertySet'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XMultiHierarchicalPropertySet'

    @abstractmethod
    def getHierarchicalPropertySetInfo(self) -> XHierarchicalPropertySetInfo_ae271245:
        """
        retrieve information about the hierarchy of properties
        """
        ...
    @abstractmethod
    def getHierarchicalPropertyValues(self, aPropertyNames: typing.Tuple[str, ...]) -> typing.Tuple[object, ...]:
        """
        The order of the values in the returned sequence will be the same as the order of the names in the argument.
        
        Unknown properties are ignored, in their place NULL will be returned.

        Raises:
            : ````
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def setHierarchicalPropertyValues(self, aHierarchicalPropertyNames: typing.Tuple[str, ...], Values: typing.Tuple[object, ...]) -> None:
        """
        sets the values of the properties with the specified nested names.
        
        The values of the properties must change before bound events are fired. The values of constrained properties should change after the vetoable events are fired, if no exception occurs.
        
        Unknown properties are ignored.

        Raises:
            com.sun.star.beans.PropertyVetoException: ``PropertyVetoException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...

__all__ = ['XMultiHierarchicalPropertySet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from .x_scenario import XScenario as XScenario_99ac0aad
from .x_scenario_enhanced import XScenarioEnhanced as XScenarioEnhanced_fca20dc3

class Scenario(XPropertySet_bc180bfa, XNamed_a6520b08, XScenario_99ac0aad, XScenarioEnhanced_fca20dc3):
    """
    Service Class

    represents a scenario in a spreadsheet document.

    See Also:
        `API Scenario <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1Scenario.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.Scenario'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BorderColor(self) -> int:
        """
        specifies the color of the border of the scenario.
        """
        ...

    @abstractproperty
    def CopyBack(self) -> bool:
        """
        specifies if the data should be copied back into the scenario.
        """
        ...

    @abstractproperty
    def CopyFormulas(self) -> bool:
        """
        specifies if the formulas are copied or only the results.
        """
        ...

    @abstractproperty
    def CopyStyles(self) -> bool:
        """
        specifies if the styles are copied.
        """
        ...

    @abstractproperty
    def IsActive(self) -> bool:
        """
        specifies if the scenario is active.
        """
        ...

    @abstractproperty
    def PrintBorder(self) -> bool:
        """
        specifies if the scenario prints a border.
        """
        ...

    @abstractproperty
    def Protected(self) -> bool:
        """
        specifies if the scenario is protected.
        """
        ...

    @abstractproperty
    def ShowBorder(self) -> bool:
        """
        specifies if the scenario shows a border.
        """
        ...


__all__ = ['Scenario']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
from abc import abstractproperty
from ..form.x_image_producer_supplier import XImageProducerSupplier as XImageProducerSupplier_37df0f8f
from .x_report_control_model import XReportControlModel as XReportControlModel_2d800f4a

class XImageControl(XImageProducerSupplier_37df0f8f, XReportControlModel_2d800f4a):
    """
    
    **since**
    
        OOo 3.2

    See Also:
        `API XImageControl <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XImageControl.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XImageControl'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XImageControl'

    @abstractproperty
    def ImageURL(self) -> str:
        """
        specifies a URL to an image to use for the control.
        """
        ...

    @abstractproperty
    def PreserveIRI(self) -> bool:
        """
        Specifies that the IRI given in the data field should be preserved, otherwise the content will be inserted in the resulting report document.
        
        If the data field contains something different as string then this attribute will be ignored.
        """
        ...

    @abstractproperty
    def ScaleMode(self) -> int:
        """
        defines how to scale the image
        
        If this property is present, it supersedes the ScaleImage property.
        
        The value of this property is one of the com.sun.star.awt.ImageScaleMode constants.
        
        **since**
        
            OOo 3.2
        """
        ...


__all__ = ['XImageControl']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .xui_configuration_listener import XUIConfigurationListener as XUIConfigurationListener_34e90f7a

class XUIConfiguration(XInterface_8f010a43):
    """
    supports to notify other implementations about changes of a user interface configuration manager.
    
    The XUIConfiguration interface is provided for user interface configuration managers which need to broadcast changes within the container; that means the actions of adding, replacing and removing elements are broadcast to listeners.
    
    This can be useful for UI to enable/disable some functions without actually accessing the data.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUIConfiguration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XUIConfiguration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XUIConfiguration'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XUIConfiguration'

    @abstractmethod
    def addConfigurationListener(self, Listener: XUIConfigurationListener_34e90f7a) -> None:
        """
        adds the specified listener to receive events when elements are changed, inserted or removed.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...
    @abstractmethod
    def removeConfigurationListener(self, Listener: XUIConfigurationListener_34e90f7a) -> None:
        """
        removes the specified listener so it does not receive any events from this user interface configuration manager.
        
        It is suggested to allow multiple registration of the same listener, thus for each time a listener is added, it has to be removed.
        """
        ...

__all__ = ['XUIConfiguration']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TableOperationMode(metaclass=UnoEnumMeta, type_name="com.sun.star.sheet.TableOperationMode", name_space="com.sun.star.sheet"):
        """Dynamically created class that represents ``com.sun.star.sheet.TableOperationMode`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.sheet.TableOperationMode import BOTH as TABLE_OPERATION_MODE_BOTH
        from com.sun.star.sheet.TableOperationMode import COLUMN as TABLE_OPERATION_MODE_COLUMN
        from com.sun.star.sheet.TableOperationMode import ROW as TABLE_OPERATION_MODE_ROW

        class TableOperationMode(uno.Enum):
            """
            Enum Class


            See Also:
                `API TableOperationMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#a91d4f5595c9dc2a8c09e532e59f395d9>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.sheet.TableOperationMode', value)

            __ooo_ns__: str = 'com.sun.star.sheet'
            __ooo_full_ns__: str = 'com.sun.star.sheet.TableOperationMode'
            __ooo_type_name__: str = 'enum'

            BOTH = TABLE_OPERATION_MODE_BOTH
            """
            is applied to rows and columns.
            """
            COLUMN = TABLE_OPERATION_MODE_COLUMN
            """
            the field is used as a column field.

            is applied to the columns.
            """
            ROW = TABLE_OPERATION_MODE_ROW
            """
            the field is used as a row field.

            is applied to the rows.
            """
    else:
        # keep document generators happy
        from ...lo.sheet.table_operation_mode import TableOperationMode as TableOperationMode


__all__ = ['TableOperationMode']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.connection
from __future__ import annotations
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XConnection(XInterface_8f010a43):
    """
    A bidirectional bytestream.
    
    You should additionally implement XConnection2.

    See Also:
        `API XConnection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1connection_1_1XConnection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.connection'
    __ooo_full_ns__: str = 'com.sun.star.connection.XConnection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.connection.XConnection'

    @abstractmethod
    def close(self) -> None:
        """
        Immediately terminates any ongoing read or write calls.
        
        All subsequent read or write calls()

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def flush(self) -> None:
        """
        Empties all internal buffers.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def getDescription(self) -> str:
        """
        A unique string describing the connection.
        
        This string is different from the arguments to XConnection.accept() and XConnector.connect(). In general, the string contains an additional handle value. For example, \"socket,host=localhost,port=2002,uniqueValue=2324\".
        """
        ...
    @abstractmethod
    def read(self, aReadBytes: uno.ByteSequence, nBytesToRead: int) -> int:
        """
        reads a requested number of bytes from the connection.
        
        This method is blocking, meaning that it always returns a bytesequence with the requested number of bytes, unless it has reached end of file (which often means, that close() has been called).
        
        please see also the readSomeBytes() method of XConnection2.

        * ``aReadBytes`` is an out direction argument.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def write(self, aData: uno.ByteSequence) -> None:
        """
        writes the given bytesequence to the stream.
        
        The method blocks until the whole sequence is written.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XConnection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..container.x_string_key_map import XStringKeyMap as XStringKeyMap_ffc60de1
    from .x_text_range import XTextRange as XTextRange_9a910ab7

class XTextMarkup(ABC):
    """
    provides functionality to markup text.
    
    **since**
    
        OOo 2.3

    See Also:
        `API XTextMarkup <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XTextMarkup.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XTextMarkup'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XTextMarkup'

    @abstractmethod
    def commitStringMarkup(self, nType: int, aIdentifier: str, nStart: int, nLength: int, xMarkupInfoContainer: XStringKeyMap_ffc60de1) -> None:
        """
        submits a new markup range.
        """
        ...
    @abstractmethod
    def commitTextRangeMarkup(self, nType: int, aIdentifier: str, xRange: XTextRange_9a910ab7, xMarkupInfoContainer: XStringKeyMap_ffc60de1) -> None:
        """
        """
        ...
    @abstractmethod
    def getMarkupInfoContainer(self) -> XStringKeyMap_ffc60de1:
        """
        obtains a container to store additional user defined text markup information.
        """
        ...

__all__ = ['XTextMarkup']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_control import XControl as XControl_7a9c098d
    from .x_control_container import XControlContainer as XControlContainer_e22d0d30
    from .x_tab_controller_model import XTabControllerModel as XTabControllerModel_fbef0dd8

class XTabController(XInterface_8f010a43):
    """
    specifies the basic operations for a tab controller.

    See Also:
        `API XTabController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XTabController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XTabController'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XTabController'

    @abstractmethod
    def activateFirst(self) -> None:
        """
        sets the focus to the first control that can be reached with the TAB key.
        """
        ...
    @abstractmethod
    def activateLast(self) -> None:
        """
        sets the focus to the last control that can be reached with the TAB key.
        """
        ...
    @abstractmethod
    def activateTabOrder(self) -> None:
        """
        activates tab order.
        """
        ...
    @abstractmethod
    def autoTabOrder(self) -> None:
        """
        enables automatic tab order.
        """
        ...
    @abstractmethod
    def getContainer(self) -> XControlContainer_e22d0d30:
        """
        returns the control container.
        """
        ...
    @abstractmethod
    def getControls(self) -> typing.Tuple[XControl_7a9c098d, ...]:
        """
        returns all controls of the control container.
        """
        ...
    @abstractmethod
    def getModel(self) -> XTabControllerModel_fbef0dd8:
        """
        returns the tab controller model.
        """
        ...
    @abstractmethod
    def setContainer(self, Container: XControlContainer_e22d0d30) -> None:
        """
        set the control container.
        """
        ...
    @abstractmethod
    def setModel(self, Model: XTabControllerModel_fbef0dd8) -> None:
        """
        sets the tab controller model.
        """
        ...

__all__ = ['XTabController']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XMaterialHolder(XInterface_8f010a43):
    """
    gives access to the material a (tool-) object is working on.
    
    Example: The introspection service allows the inspection of an object's properties and methods. The result is represented as XIntrospectionAccess interface. The inspected object then is the material attached to the introspection tool and an implementation of XIntrospectionAccess should also support XMaterialHolder to give access to this material.

    See Also:
        `API XMaterialHolder <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1beans_1_1XMaterialHolder.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.XMaterialHolder'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.beans.XMaterialHolder'

    @abstractmethod
    def getMaterial(self) -> object:
        """
        returns the material that is connected to this (tool-) object
        """
        ...

__all__ = ['XMaterialHolder']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
    from .x_search_descriptor import XSearchDescriptor as XSearchDescriptor_ef600d93

class XSearchable(XInterface_8f010a43):
    """
    enables the object to look for specified contents of the object (in particular, for a text range which contains a specific string pattern).
    
    Example: in a com.sun.star.text.TextDocument: set all \"search for\" to bold using findFirst()/findNext():

    See Also:
        `API XSearchable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XSearchable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XSearchable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XSearchable'

    @abstractmethod
    def createSearchDescriptor(self) -> XSearchDescriptor_ef600d93:
        """
        creates a SearchDescriptor which contains properties that specify a search in this container.
        """
        ...
    @abstractmethod
    def findAll(self, xDesc: XSearchDescriptor_ef600d93) -> XIndexAccess_f0910d6d:
        """
        searches the contained texts for all occurrences of whatever is specified.
        """
        ...
    @abstractmethod
    def findFirst(self, xDesc: XSearchDescriptor_ef600d93) -> XInterface_8f010a43:
        """
        searches the contained texts for the next occurrence of whatever is specified.
        """
        ...
    @abstractmethod
    def findNext(self, xStartAt: XInterface_8f010a43, xDesc: XSearchDescriptor_ef600d93) -> XInterface_8f010a43:
        """
        searches the contained texts for the next occurrence of whatever is specified.
        """
        ...

__all__ = ['XSearchable']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ui
# Libre Office Version: 7.4
from .x_module_ui_configuration_manager_supplier import XModuleUIConfigurationManagerSupplier as XModuleUIConfigurationManagerSupplier_20b814a9


class theModuleUIConfigurationManagerSupplier(XModuleUIConfigurationManagerSupplier_20b814a9):
    """
    Singleton Class

    specifies a central user interface configuration provider which gives access to module based user interface configuration managers.
    
    Controls module based user interface configuration managers.
    
    There can only exist one user interface configuration manager for a module. A user interface configuration manager supports to get and set user interface configuration data for configurable user interface elements.
    
    Prior to LibreOffice 4.3, this singleton was only available as a (single-instance) ModuleUIConfigurationManagerSupplier service.
    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API theModuleUIConfigurationManagerSupplier <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1ui_1_1theModuleUIConfigurationManagerSupplier.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.theModuleUIConfigurationManagerSupplier'
    __ooo_type_name__: str = 'singleton'
    _instance = None

    def __new__(cls, *args, **kwargs):
        # single instance only allowed
        if cls._instance is None:
            cls._instance = super().__new__(cls, *args, **kwargs)
        return cls._instance


__all__ = ['theModuleUIConfigurationManagerSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_hierarchical_storage_access import XHierarchicalStorageAccess as XHierarchicalStorageAccess_876b1143
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from .x_extended_storage_stream import XExtendedStorageStream as XExtendedStorageStream_46750fcf

class XHierarchicalStorageAccess2(XHierarchicalStorageAccess_876b1143):
    """
    This interface extends XHierarchicalStorageAccess interface.

    See Also:
        `API XHierarchicalStorageAccess2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XHierarchicalStorageAccess2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XHierarchicalStorageAccess2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XHierarchicalStorageAccess2'

    @abstractmethod
    def openEncryptedStreamByHierarchicalName(self, sStreamName: str, nOpenMode: int, aEncryptionData: typing.Tuple[NamedValue_a37a0af3, ...]) -> XExtendedStorageStream_46750fcf:
        """
        allows to get access to a child encrypted stream with encryption data using hierarchical path.
        
        If storage does not allow any encryption this method will always throw com.sun.star.packages.NoEncryptionException.
        
        In case the stream is open in readonly mode the com.sun.star.io.XStream.getOutputStream() method will return an empty reference.

        Raises:
            com.sun.star.embed.InvalidStorageException: ``InvalidStorageException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.packages.NoEncryptionException: ``NoEncryptionException``
            com.sun.star.packages.WrongPasswordException: ``WrongPasswordException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.embed.StorageWrappedTargetException: ``StorageWrappedTargetException``
        """
        ...

__all__ = ['XHierarchicalStorageAccess2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TabAlign(metaclass=UnoEnumMeta, type_name="com.sun.star.style.TabAlign", name_space="com.sun.star.style"):
        """Dynamically created class that represents ``com.sun.star.style.TabAlign`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.style.TabAlign import CENTER as TAB_ALIGN_CENTER
        from com.sun.star.style.TabAlign import DECIMAL as TAB_ALIGN_DECIMAL
        from com.sun.star.style.TabAlign import DEFAULT as TAB_ALIGN_DEFAULT
        from com.sun.star.style.TabAlign import LEFT as TAB_ALIGN_LEFT
        from com.sun.star.style.TabAlign import RIGHT as TAB_ALIGN_RIGHT

        class TabAlign(uno.Enum):
            """
            Enum Class


            See Also:
                `API TabAlign <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style.html#a806c06853615662029f86b19111fe0a2>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.style.TabAlign', value)

            __ooo_ns__: str = 'com.sun.star.style'
            __ooo_full_ns__: str = 'com.sun.star.style.TabAlign'
            __ooo_type_name__: str = 'enum'

            CENTER = TAB_ALIGN_CENTER
            """
            set the horizontal alignment to the center between the margins from the container object

            The text range is centered between the previous tabulator (or the left border, if none) and this tabulator.

            adjusted to the center
            """
            DECIMAL = TAB_ALIGN_DECIMAL
            """
            The decimal point of the text range to the left of this tabulator is aligned to the position of this tabulator.
            """
            DEFAULT = TAB_ALIGN_DEFAULT
            """
            The default alignment for tabulators is applied.
            """
            LEFT = TAB_ALIGN_LEFT
            """
            set the horizontal alignment to the left margin from the container object

            The text range is left-aligned between the previous tabulator (or the left border, if none) and this tabulator.

            adjusted to the left border

            The page style is only used for left pages.
            """
            RIGHT = TAB_ALIGN_RIGHT
            """
            set the horizontal alignment to the right margin from the container object

            The text range is right-aligned between the previous tabulator (or the left border, if none) and this tabulator.

            adjusted to the right border

            The page style is only used for right pages.
            """
    else:
        # keep document generators happy
        from ...lo.style.tab_align import TabAlign as TabAlign


__all__ = ['TabAlign']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdbcx
from __future__ import annotations
from abc import abstractproperty
from ..sdbc.result_set import ResultSet as ResultSet_8ecf0a4f
from .x_delete_rows import XDeleteRows as XDeleteRows_af5c0b72
from .x_row_locate import XRowLocate as XRowLocate_a4730b04
from ..util.x_cancellable import XCancellable as XCancellable_afc30b64

class ResultSet(ResultSet_8ecf0a4f, XDeleteRows_af5c0b72, XRowLocate_a4730b04, XCancellable_afc30b64):
    """
    Service Class

    extends the SDBC ResultSet by the possibility of bookmark positioning, canceling the positioning, and updating of rows.

    See Also:
        `API ResultSet <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdbcx_1_1ResultSet.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdbcx'
    __ooo_full_ns__: str = 'com.sun.star.sdbcx.ResultSet'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CanUpdateInsertedRows(self) -> bool:
        """
        returns whether the result set supports updating of newly inserted rows.
        
        This may not work, as the result set may contain automatic generated data which is used as key information.
        """
        ...

    @abstractproperty
    def IsBookmarkable(self) -> bool:
        """
        returns if the result set supports bookmark navigation.
        """
        ...


__all__ = ['ResultSet']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script.provider
# Libre Office Version: 7.4
from .x_script_provider_factory import XScriptProviderFactory as XScriptProviderFactory_3ce1426


class theMasterScriptProviderFactory(XScriptProviderFactory_3ce1426):
    """
    Singleton Class

    The one and only MasterScriptProviderFactory.
    
    To get the singleton call getValueByName on the component context

    See Also:
        `API theMasterScriptProviderFactory <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1script_1_1provider_1_1theMasterScriptProviderFactory.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.script.provider'
    __ooo_full_ns__: str = 'com.sun.star.script.provider.theMasterScriptProviderFactory'
    __ooo_type_name__: str = 'singleton'
    _instance = None

    def __new__(cls, *args, **kwargs):
        # single instance only allowed
        if cls._instance is None:
            cls._instance = super().__new__(cls, *args, **kwargs)
        return cls._instance


__all__ = ['theMasterScriptProviderFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.xml.crypto.cipher_id import CipherID as CipherID
from ....lo.xml.crypto.digest_id import DigestID as DigestID
from ....lo.xml.crypto.gpgse_initializer import GPGSEInitializer as GPGSEInitializer
from ....lo.xml.crypto.nss_initializer import NSSInitializer as NSSInitializer
from ....lo.xml.crypto.nss_profile import NSSProfile as NSSProfile
from ....lo.xml.crypto.se_initializer import SEInitializer as SEInitializer
from ....lo.xml.crypto.security_environment import SecurityEnvironment as SecurityEnvironment
from ....lo.xml.crypto.security_operation_status import SecurityOperationStatus as SecurityOperationStatus
from ....lo.xml.crypto.x_certificate_creator import XCertificateCreator as XCertificateCreator
from ....lo.xml.crypto.x_cipher_context import XCipherContext as XCipherContext
from ....lo.xml.crypto.x_cipher_context_supplier import XCipherContextSupplier as XCipherContextSupplier
from ....lo.xml.crypto.x_digest_context import XDigestContext as XDigestContext
from ....lo.xml.crypto.x_digest_context_supplier import XDigestContextSupplier as XDigestContextSupplier
from ....lo.xml.crypto.xml_encryption_exception import XMLEncryptionException as XMLEncryptionException
from ....lo.xml.crypto.xml_security_context import XMLSecurityContext as XMLSecurityContext
from ....lo.xml.crypto.xml_signature import XMLSignature as XMLSignature
from ....lo.xml.crypto.xml_signature_exception import XMLSignatureException as XMLSignatureException
from ....lo.xml.crypto.xnss_initializer import XNSSInitializer as XNSSInitializer
from ....lo.xml.crypto.xse_initializer import XSEInitializer as XSEInitializer
from ....lo.xml.crypto.x_security_environment import XSecurityEnvironment as XSecurityEnvironment
from ....lo.xml.crypto.x_uri_binding import XUriBinding as XUriBinding
from ....lo.xml.crypto.xxml_encryption import XXMLEncryption as XXMLEncryption
from ....lo.xml.crypto.xxml_encryption_template import XXMLEncryptionTemplate as XXMLEncryptionTemplate
from ....lo.xml.crypto.xxml_security_context import XXMLSecurityContext as XXMLSecurityContext
from ....lo.xml.crypto.xxml_security_template import XXMLSecurityTemplate as XXMLSecurityTemplate
from ....lo.xml.crypto.xxml_signature import XXMLSignature as XXMLSignature
from ....lo.xml.crypto.xxml_signature_template import XXMLSignatureTemplate as XXMLSignatureTemplate



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class MacroExecMode(metaclass=UnoConstMeta, type_name="com.sun.star.document.MacroExecMode", name_space="com.sun.star.document"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.document.MacroExecMode``"""
        pass

    class MacroExecModeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.document.MacroExecMode", name_space="com.sun.star.document"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.document.MacroExecMode`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.document import MacroExecMode as MacroExecMode
    else:
        # keep document generators happy
        from ...lo.document.macro_exec_mode import MacroExecMode as MacroExecMode

    class MacroExecModeEnum(IntEnum):
        """
        Enum of Const Class MacroExecMode

        Specify whether a macro can be executed.
        
        **since**
        
            OOo 1.1.2
        """
        NEVER_EXECUTE = MacroExecMode.NEVER_EXECUTE
        """
        A macro should not be executed at all.
        """
        FROM_LIST = MacroExecMode.FROM_LIST
        """
        Execute macros from secure list quietly.
        
        If a macro is not in the list a confirmation for it executing will appear.
        """
        ALWAYS_EXECUTE = MacroExecMode.ALWAYS_EXECUTE
        """
        Execute any macro, macros signed with trusted certificates and macros from secure list are executed quietly.
        
        If the macro is neither in secure list nor signed a conformation will be requested.
        """
        USE_CONFIG = MacroExecMode.USE_CONFIG
        """
        Use configuration to retrieve macro settings.
        
        In case a user confirmation is required a dialog is output.
        """
        ALWAYS_EXECUTE_NO_WARN = MacroExecMode.ALWAYS_EXECUTE_NO_WARN
        """
        A macro should be executed always no conformation should be provided.
        """
        USE_CONFIG_REJECT_CONFIRMATION = MacroExecMode.USE_CONFIG_REJECT_CONFIRMATION
        """
        Use configuration to retrieve macro settings.
        
        Treat cases when user confirmation required as rejected.
        """
        USE_CONFIG_APPROVE_CONFIRMATION = MacroExecMode.USE_CONFIG_APPROVE_CONFIRMATION
        """
        Use configuration to retrieve macro settings.
        
        Treat cases when user confirmation required as approved.
        """
        FROM_LIST_NO_WARN = MacroExecMode.FROM_LIST_NO_WARN
        """
        Execute only macros from secure list.
        
        Macros that are not from the list are not executed.
        """
        FROM_LIST_AND_SIGNED_WARN = MacroExecMode.FROM_LIST_AND_SIGNED_WARN
        """
        Execute only macros from secure list or macros that are signed by trusted certificates.
        
        If the macro is neither in secure list nor signed it will not be executed.
        
        If the macro is signed with unknown certificate a warning will appear. The macro either will not be executed or if the warning allows conformation, it will be executed after user agrees.
        """
        FROM_LIST_AND_SIGNED_NO_WARN = MacroExecMode.FROM_LIST_AND_SIGNED_NO_WARN
        """
        Execute only macros from secure list or macros that are signed by trusted certificates.
        
        No warning/conformation should be shown.
        """

__all__ = ['MacroExecMode', 'MacroExecModeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XMergeableCellRange(XInterface_8f010a43):
    """
    represents a range of cells that can possibly be merged or unmerged.

    See Also:
        `API XMergeableCellRange <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1table_1_1XMergeableCellRange.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.XMergeableCellRange'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.table.XMergeableCellRange'

    @abstractmethod
    def isMergeable(self) -> bool:
        """
        """
        ...
    @abstractmethod
    def merge(self) -> None:
        """
        merges the area specified by this range.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def split(self, Columns: int, Rows: int) -> None:
        """
        splits the cells in this range.
        
        This will be done by inserting rows and columns if needed or unmerging cells that are already split.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XMergeableCellRange']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
from abc import abstractmethod
from .x_library_container2 import XLibraryContainer2 as XLibraryContainer2_1c490e9f

class XLibraryContainer3(XLibraryContainer2_1c490e9f):
    """
    Extension of XLibraryContainer2.

    See Also:
        `API XLibraryContainer3 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XLibraryContainer3.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XLibraryContainer3'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XLibraryContainer3'

    @abstractmethod
    def getOriginalLibraryLinkURL(self, Name: str) -> str:
        """
        returns the location of the library link target.
        
        The returned URL is literally the same as the one provided in XLibraryContainer.createLibraryLink(). Otherwise the behavior is the same as XLibraryContainer2.getLibraryLinkURL()

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XLibraryContainer3']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class ChartAxisMarks(metaclass=UnoConstMeta, type_name="com.sun.star.chart.ChartAxisMarks", name_space="com.sun.star.chart"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.chart.ChartAxisMarks``"""
        pass

    class ChartAxisMarksEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.chart.ChartAxisMarks", name_space="com.sun.star.chart"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.chart.ChartAxisMarks`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.chart import ChartAxisMarks as ChartAxisMarks
    else:
        # keep document generators happy
        from ...lo.chart.chart_axis_marks import ChartAxisMarks as ChartAxisMarks

    class ChartAxisMarksEnum(IntEnum):
        """
        Enum of Const Class ChartAxisMarks

        With these constants you can specify how the tick-marks of an axis are displayed.
        
        You can combine INNER and OUTER with an arithmetical or-operation to get tick-marks that extend in both directions.
        """
        NONE = ChartAxisMarks.NONE
        """
        Do not display any marks.
        """
        INNER = ChartAxisMarks.INNER
        """
        Display marks that point into the diagram area.
        """
        OUTER = ChartAxisMarks.OUTER
        """
        Display marks that point out of the diagram area.
        """

__all__ = ['ChartAxisMarks', 'ChartAxisMarksEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.smarttags.smart_tag_action import SmartTagAction as SmartTagAction
from ...lo.smarttags.smart_tag_recognizer import SmartTagRecognizer as SmartTagRecognizer
from ...lo.smarttags.smart_tag_recognizer_mode import SmartTagRecognizerMode as SmartTagRecognizerMode
from ...lo.smarttags.x_range_based_smart_tag_recognizer import XRangeBasedSmartTagRecognizer as XRangeBasedSmartTagRecognizer
from ...lo.smarttags.x_smart_tag_action import XSmartTagAction as XSmartTagAction
from ...lo.smarttags.x_smart_tag_recognizer import XSmartTagRecognizer as XSmartTagRecognizer



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.property_set import PropertySet as PropertySet_b0e70ba2
from .x_axis import XAxis as XAxis_796b0939
from .x_titled import XTitled as XTitled_8d490a0a
from ..drawing.line_properties import LineProperties as LineProperties_f13f0da9
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
if typing.TYPE_CHECKING:
    from ..awt.size import Size as Size_576707ef
    from com.sun.star.chart.ChartAxisArrangeOrderType import ChartAxisArrangeOrderTypeProto
    from com.sun.star.chart.ChartAxisPosition import ChartAxisPositionProto
    from com.sun.star.chart.ChartAxisLabelPosition import ChartAxisLabelPositionProto
    from com.sun.star.chart.ChartAxisMarkPosition import ChartAxisMarkPositionProto

class Axis(PropertySet_b0e70ba2, LineProperties_f13f0da9, CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, XAxis_796b0939, XTitled_8d490a0a):
    """
    Service Class

    
    **since**
    
        LibreOffice 4.3

    See Also:
        `API Axis <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1Axis.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.Axis'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ArrangeOrder(self) -> ChartAxisArrangeOrderTypeProto:
        """
        Determines how to stagger the labels at the axis (side by side, even, odd, auto )
        """
        ...

    @abstractproperty
    def BuiltInUnit(self) -> str:
        """
        Determines built in display unit value for axis.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def CrossoverPosition(self) -> ChartAxisPositionProto:
        """
        Determines where the axis crosses the other axis.
        """
        ...

    @abstractproperty
    def CrossoverValue(self) -> float:
        """
        Determines the scale value on the other axis when CrossoverPosition is set to VALUE.
        """
        ...

    @abstractproperty
    def DisplayLabels(self) -> bool:
        """
        Determines whether to display text at the axis or not.
        """
        ...

    @abstractproperty
    def DisplayUnits(self) -> bool:
        """
        Determines display units are available for axis.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def LabelPosition(self) -> ChartAxisLabelPositionProto:
        """
        Determines where the axis labels are placed.
        """
        ...

    @abstractproperty
    def MajorOrigin(self) -> int:
        """
        This attribute specifies the shift of the first major tick from the origin.
        
        **since**
        
            LibreOffice 7.0
        """
        ...

    @abstractproperty
    def MajorTickmarks(self) -> int:
        """
        determines what kind of tickmarks should be shown for major ticks.
        """
        ...

    @abstractproperty
    def MarkPosition(self) -> ChartAxisMarkPositionProto:
        """
        Determines where the interval marks are placed.
        """
        ...

    @abstractproperty
    def MinorTickmarks(self) -> int:
        """
        determines what kind of tickmarks should be shown for minor ticks.
        """
        ...

    @abstractproperty
    def NumberFormat(self) -> int:
        """
        A NumberFormat key.
        
        If this property is not set, it is treated as auto. This means linked to the source format.
        
        To determine a source format, the axis can query the XDataSequences used by the data series attached to it (see XDataSequence.getNumberFormatKeyByIndex()).
        """
        ...

    @abstractproperty
    def ReferencePageSize(self) -> Size_576707ef:
        """
        """
        ...

    @abstractproperty
    def Show(self) -> bool:
        """
        Determines, whether the axis should be rendered by the view.
        """
        ...

    @abstractproperty
    def StackCharacters(self) -> bool:
        """
        Determines whether the characters in a single labels should be stacked one upon each other.
        """
        ...

    @abstractproperty
    def TextBreak(self) -> bool:
        """
        Determines whether the labels are allowed to break into more than one line.
        """
        ...

    @abstractproperty
    def TextOverlap(self) -> bool:
        """
        Determines whether the labels are allowed to overlap.
        """
        ...

    @abstractproperty
    def TextRotation(self) -> float:
        """
        Determines the rotation of the text labels in degrees.
        """
        ...

    @abstractproperty
    def TryStaggeringFirst(self) -> bool:
        """
        Compatibility option: determines which strategy should be tried first for fixing axis labels overlapping issues.
        
        **since**
        
            LibreOffice 5.1
        """
        ...


__all__ = ['Axis']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.mozilla
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from com.sun.star.mozilla.MozillaProductType import MozillaProductTypeProto

class XProfileManager(XInterface_8f010a43):
    """
    is the interface to boot up and switch Mozilla/Thunderbird profiles

    See Also:
        `API XProfileManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1mozilla_1_1XProfileManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.mozilla'
    __ooo_full_ns__: str = 'com.sun.star.mozilla.XProfileManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.mozilla.XProfileManager'

    @abstractmethod
    def bootupProfile(self, product: MozillaProductTypeProto, profileName: str) -> int:
        """
        attempts to init XPCOM runtime using given profile.
        """
        ...
    @abstractmethod
    def getCurrentProduct(self) -> MozillaProductTypeProto:
        """
        attempts to get the current product.
        """
        ...
    @abstractmethod
    def getCurrentProfile(self) -> str:
        """
        attempts to get the current profile name.
        """
        ...
    @abstractmethod
    def isCurrentProfileLocked(self) -> bool:
        """
        attempts to check whether the current profile locked or not
        """
        ...
    @abstractmethod
    def setCurrentProfile(self, product: MozillaProductTypeProto, profileName: str) -> str:
        """
        attempts to set the current used profile name for the given product.
        """
        ...
    @abstractmethod
    def shutdownProfile(self) -> int:
        """
        attempts to shutdown the current profile.
        """
        ...

__all__ = ['XProfileManager']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .double_sequence_sequence import DoubleSequenceSequence as DoubleSequenceSequence_6b8010c1


class PolyPolygonShape3D(object):
    """
    Struct Class

    specifies the coordinates of a 3-dimensional poly polygon.

    See Also:
        `API PolyPolygonShape3D <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1PolyPolygonShape3D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.PolyPolygonShape3D'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.PolyPolygonShape3D'
    """Literal Constant ``com.sun.star.drawing.PolyPolygonShape3D``"""

    def __init__(self, SequenceX: typing.Optional[DoubleSequenceSequence_6b8010c1] = DoubleSequenceSequence_6b8010c1(()), SequenceY: typing.Optional[DoubleSequenceSequence_6b8010c1] = DoubleSequenceSequence_6b8010c1(()), SequenceZ: typing.Optional[DoubleSequenceSequence_6b8010c1] = DoubleSequenceSequence_6b8010c1(())) -> None:
        """
        Constructor

        Arguments:
            SequenceX (DoubleSequenceSequence, optional): SequenceX value.
            SequenceY (DoubleSequenceSequence, optional): SequenceY value.
            SequenceZ (DoubleSequenceSequence, optional): SequenceZ value.
        """
        super().__init__()

        if isinstance(SequenceX, PolyPolygonShape3D):
            oth: PolyPolygonShape3D = SequenceX
            self.SequenceX = oth.SequenceX
            self.SequenceY = oth.SequenceY
            self.SequenceZ = oth.SequenceZ
            return

        kargs = {
            "SequenceX": SequenceX,
            "SequenceY": SequenceY,
            "SequenceZ": SequenceZ,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._sequence_x = kwargs["SequenceX"]
        self._sequence_y = kwargs["SequenceY"]
        self._sequence_z = kwargs["SequenceZ"]


    @property
    def SequenceX(self) -> DoubleSequenceSequence_6b8010c1:
        return self._sequence_x

    @SequenceX.setter
    def SequenceX(self, value: DoubleSequenceSequence_6b8010c1) -> None:
        self._sequence_x = value

    @property
    def SequenceY(self) -> DoubleSequenceSequence_6b8010c1:
        return self._sequence_y

    @SequenceY.setter
    def SequenceY(self, value: DoubleSequenceSequence_6b8010c1) -> None:
        self._sequence_y = value

    @property
    def SequenceZ(self) -> DoubleSequenceSequence_6b8010c1:
        return self._sequence_z

    @SequenceZ.setter
    def SequenceZ(self, value: DoubleSequenceSequence_6b8010c1) -> None:
        self._sequence_z = value


__all__ = ['PolyPolygonShape3D']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt.tree
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from ...lang.event_object import EventObject as EventObject_a3d70b03
from ...uno.x_interface import XInterface as XInterface_8f010a43
import typing
from .x_tree_node import XTreeNode as XTreeNode_baaf0ba0


class TreeDataModelEvent(EventObject_a3d70b03):
    """
    Struct Class

    An event used by a XTreeDataModel to notify changes in the data model to the XTreeControl.
    
    You usually need to fill this event only if you implement the XTreeDataModel yourself.

    See Also:
        `API TreeDataModelEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1tree_1_1TreeDataModelEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tree'
    __ooo_full_ns__: str = 'com.sun.star.awt.tree.TreeDataModelEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.tree.TreeDataModelEvent'
    """Literal Constant ``com.sun.star.awt.tree.TreeDataModelEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Nodes: typing.Optional[typing.Tuple[XTreeNode_baaf0ba0, ...]] = (), ParentNode: typing.Optional[XTreeNode_baaf0ba0] = None) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Nodes (typing.Tuple[XTreeNode, ...], optional): Nodes value.
            ParentNode (XTreeNode, optional): ParentNode value.
        """

        if isinstance(Source, TreeDataModelEvent):
            oth: TreeDataModelEvent = Source
            self.Source = oth.Source
            self.Nodes = oth.Nodes
            self.ParentNode = oth.ParentNode
            return

        kargs = {
            "Source": Source,
            "Nodes": Nodes,
            "ParentNode": ParentNode,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._nodes = kwargs["Nodes"]
        self._parent_node = kwargs["ParentNode"]
        inst_keys = ('Nodes', 'ParentNode')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Nodes(self) -> typing.Tuple[XTreeNode_baaf0ba0, ...]:
        """
        contains the changed, added or removed nodes.
        
        All nodes must have ParentNode as parent.
        """
        return self._nodes

    @Nodes.setter
    def Nodes(self, value: typing.Tuple[XTreeNode_baaf0ba0, ...]) -> None:
        self._nodes = value

    @property
    def ParentNode(self) -> XTreeNode_baaf0ba0:
        """
        holds the parent node for changed, added or removed nodes.
        
        If this is null, Nodes must contain only the root node
        """
        return self._parent_node

    @ParentNode.setter
    def ParentNode(self, value: XTreeNode_baaf0ba0) -> None:
        self._parent_node = value


__all__ = ['TreeDataModelEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XActivateListener(XEventListener_c7230c4a):
    """
    makes it possible to receive activate events.

    See Also:
        `API XActivateListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XActivateListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XActivateListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XActivateListener'

    @abstractmethod
    def windowActivated(self, e: EventObject_a3d70b03) -> None:
        """
        is invoked when a window is activated.
        
        A window is activated if a child or itself got the focus.
        """
        ...
    @abstractmethod
    def windowDeactivated(self, e: EventObject_a3d70b03) -> None:
        """
        is invoked when a window is deactivated.
        
        A window is deactivated if a child or itself lost the focus.
        """
        ...

__all__ = ['XActivateListener']

